@@ -76,6 +76,9 @@ module.exports = {
     secretAccessKey: undefined,
     region: undefined
   },
+  s3bucket: undefined,
+  s3folder: 'uploads',
+  s3publicFiles: false,
   minio: {
     accessKey: undefined,
     secretKey: undefined,
@@ -83,7 +86,6 @@ module.exports = {
     secure: true,
     port: 9000
   },
-  s3bucket: undefined,
   azure: {
     connectionString: undefined,
     container: undefined
