@@ -57,6 +57,9 @@ module.exports = {
     region: process.env.CMD_S3_REGION,
     endpoint: process.env.CMD_S3_ENDPOINT
   },
+  s3bucket: process.env.CMD_S3_BUCKET,
+  s3folder: process.env.CMD_S3_FOLDER,
+  s3publicFiles: process.env.CMD_S3_PUBLIC_FILES,
   minio: {
     accessKey: process.env.CMD_MINIO_ACCESS_KEY,
     secretKey: process.env.CMD_MINIO_SECRET_KEY,
@@ -67,7 +70,6 @@ module.exports = {
   lutim: {
     url: process.env.CMD_LUTIM_URL
   },
-  s3bucket: process.env.CMD_S3_BUCKET,
   azure: {
     connectionString: process.env.CMD_AZURE_CONNECTION_STRING,
     container: process.env.CMD_AZURE_CONTAINER
