@@ -73,7 +73,7 @@ const umzug = new Umzug({
   },
   storage: 'sequelize',
   storageOptions: {
-    sequelize: sequelize
+    sequelize
   }
 })
 
