@@ -41,7 +41,7 @@ passport.use(new LDAPStrategy({
 
   const profile = {
     id: 'LDAP-' + uuid,
-    username: username,
+    username,
     displayName: user.displayName,
     emails: user.mail ? Array.isArray(user.mail) ? user.mail : [user.mail] : [],
     avatarUrl: null,
