@@ -75,8 +75,8 @@ exports.showNote = function (req, res, next) {
       'X-Robots-Tag': 'noindex, nofollow' // prevent crawling
     })
     return res.render('hedgedoc.ejs', {
-      title: title,
-      opengraph: opengraph
+      title,
+      opengraph
     })
   })
 }
