@@ -98,12 +98,12 @@ exports.getPublishData = function (req, res, note, callback) {
   title = models.Note.generateWebTitle(meta.title || title)
   const ogdata = models.Note.parseOpengraph(meta, title)
   const data = {
-    title: title,
+    title,
     description: meta.description || (markdown ? models.Note.generateDescription(markdown) : null),
     lang: meta.lang || null,
     viewcount: note.viewcount,
-    createtime: createtime,
-    updatetime: updatetime,
+    createtime,
+    updatetime,
     body: markdown,
     theme: meta.slideOptions && isRevealTheme(meta.slideOptions.theme),
     meta: JSON.stringify(extracted.meta),
