@@ -70,7 +70,7 @@ statusRouter.post('/temp', urlencodedParser, function (req, res) {
     } else {
       logger.debug(`SERVER received temp from [${host}]: ${req.body.data}`)
       models.Temp.create({
-        data: data
+        data
       }).then(function (temp) {
         if (temp) {
           res.header('Access-Control-Allow-Origin', '*')
